import React, {FunctionComponent} from 'react';
import styled, {css} from 'styled-components';
import {ThemeConsumer} from '../../ThemeProvider';

function getSpaceSize(props) {
  const {theme, tiny, small, normal, large, huge} = props;

  switch (true) {
    case tiny:
      return theme.size.tiny;
    case small:
      return theme.size.small;
    case normal:
      return theme.size.normal;
    case large:
      return theme.size.large;
    case huge:
      return theme.size.huge;
    default:
      return theme.size.normal;
  }
}

export const HorizontalSpace = styled.div`
  display: inline-block;
  width: ${(props)  => getSpaceSize(props)};
  height: 0;
  ${({flex}) => flex ? css`flex: 1 0 auto;` : ''}
`;

export const VerticalSpace = styled.div`
  display: block;
  width: 0;
  height: ${(props)  => getSpaceSize(props)};
  ${({flex}) => flex ? css`flex: 1 0 auto;` : ''}
`;

declare interface ISpaceProps {
  vertical?: boolean;
  tiny?: boolean;
  small?: boolean;
  normal?: boolean;
  large?: boolean;
  huge?: boolean;
  flex?: boolean;
}

export const Space: FunctionComponent<ISpaceProps> = ({vertical, ...rest}) => {
  return (
    <ThemeConsumer component="space">
      {vertical ? <VerticalSpace {...rest}/> : <HorizontalSpace {...rest}/>}
    </ThemeConsumer>
  );
};
